==> estateplat-common-1.2.4-20210318.025635-671-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxZgfSfpjjg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-最高法-司法判决结果
 */
@Table(name = "xxgx_zgf_sfpjjg")
public class XxgxZgfSfpjjg {
    @Id
    private String sfpjjgid;//司法判决结果id
    private String cxsqdh;//查询申请单号
    private String stm;//实体码
    private String ah;//案号
    private String gshah;//格式化案号
    private String qlrmc;//当事人姓名
    private String zjhm;//证件号码
    private String wsnr;//文书内容
    private String proid;//项目id

    public String getSfpjjgid() {
        return sfpjjgid;
    }

    public void setSfpjjgid(String sfpjjgid) {
        this.sfpjjgid = sfpjjgid;
    }

    public String getCxsqdh() {
        return cxsqdh;
    }

    public void setCxsqdh(String cxsqdh) {
        this.cxsqdh = cxsqdh;
    }

    public String getStm() {
        return stm;
    }

    public void setStm(String stm) {
        this.stm = stm;
    }

    public String getAh() {
        return ah;
    }

    public void setAh(String ah) {
        this.ah = ah;
    }

    public String getGshah() {
        return gshah;
    }

    public void setGshah(String gshah) {
        this.gshah = gshah;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getWsnr() {
        return wsnr;
    }

    public void setWsnr(String wsnr) {
        this.wsnr = wsnr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20210511.022010-745-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxZgfSfpjjg.java <==
package cn.gtmap.estateplat.model.server.core;

import com.alibaba.fastjson.annotation.JSONField;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-最高法-司法判决结果
 */
@Table(name = "xxgx_zgf_sfpjjg")
public class XxgxZgfSfpjjg {
    @Id
    private String sfpjjgid;//司法判决结果id
    private String cxsqdh;//查询申请单号
    private String stm;//实体码
    private String ah;//案号
    private String gshah;//格式化案号
    private String qlrmc;//当事人姓名
    private String zjhm;//证件号码
    private String wsnr;//文书内容
    private String proid;//项目id
    private String cxzt;//查询状态
    private String ajbh;//案件编号
    private Date cxsqsj;//查询申请时间

    public String getSfpjjgid() {
        return sfpjjgid;
    }

    public void setSfpjjgid(String sfpjjgid) {
        this.sfpjjgid = sfpjjgid;
    }

    public String getCxsqdh() {
        return cxsqdh;
    }

    public void setCxsqdh(String cxsqdh) {
        this.cxsqdh = cxsqdh;
    }

    public String getStm() {
        return stm;
    }

    public void setStm(String stm) {
        this.stm = stm;
    }

    public String getAh() {
        return ah;
    }

    public void setAh(String ah) {
        this.ah = ah;
    }

    public String getGshah() {
        return gshah;
    }

    public void setGshah(String gshah) {
        this.gshah = gshah;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getWsnr() {
        return wsnr;
    }

    public void setWsnr(String wsnr) {
        this.wsnr = wsnr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCxzt() {
        return cxzt;
    }

    public void setCxzt(String cxzt) {
        this.cxzt = cxzt;
    }

    public String getAjbh() {
        return ajbh;
    }

    public void setAjbh(String ajbh) {
        this.ajbh = ajbh;
    }

    public Date getCxsqsj() {
        return cxsqsj;
    }

    public void setCxsqsj(Date cxsqsj) {
        this.cxsqsj = cxsqsj;
    }
}
